@@ -37,7 +37,7 @@ from rednotebook.util import filesystem
 from rednotebook.util import dates
 from rednotebook.util import utils
 
-use_mathjax = True
+use_mathjax = False
 
 mathjax_header = '''\
 <script src="/home/jendrik/projects/RedNotebook/journalgeist/rednotebook/external/mathjax/MathJax.js">
